.. only:: html

   .. _gallery-index:

   Gallery
   =======

   Acoustics
   ^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/acoustics-acoustics.png
             :target: acoustics-acoustics.html

             :ref:`Acoustic pressure distribution <acoustics-acoustics>`

        - .. figure:: ../images/gallery/thumbnails/acoustics-acoustics3d_Omega_1.png
             :target: acoustics-acoustics3d.html

             :ref:`Acoustic pressure distribution in 3D <acoustics-acoustics3d>`

        - .. figure:: ../images/gallery/thumbnails/acoustics-helmholtz_apartment.png
             :target: acoustics-helmholtz_apartment.html

             :ref:`A script demonstrating the solution of the scalar Helmholtz equation for a situation inspired by the physical problem of WiFi propagation in an apartment <acoustics-helmholtz_apartment>`

      * - .. figure:: ../images/gallery/thumbnails/acoustics-vibro_acoustic3d_Gamma0.png
             :target: acoustics-vibro_acoustic3d.html

             :ref:`Vibro-acoustic problem 3D acoustic domain with 2D perforated deforming interface <acoustics-vibro_acoustic3d>`

        - ..

        - ..

   Dg
   ^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/dg-advection_1D.png
             :target: dg-advection_1D.html

             :ref:`Transient advection equation in 1D solved using discontinous galerkin method <dg-advection_1D>`

        - ..

        - ..

   Diffusion
   ^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/diffusion-cube.png
             :target: diffusion-cube.html

             :ref:`Laplace equation (eg: temperature distribution) on a cube geometry with different boundary condition values on the cube sides <diffusion-cube>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-darcy_flow_multicomp.png
             :target: diffusion-darcy_flow_multicomp.html

             :ref:`Each of the two equations describes a flow in one compartment of a porous medium <diffusion-darcy_flow_multicomp>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-laplace_1d.png
             :target: diffusion-laplace_1d.html

             :ref:`Laplace equation in 1D with a variable coefficient <diffusion-laplace_1d>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-laplace_coupling_lcbcs.png
             :target: diffusion-laplace_coupling_lcbcs.html

             :ref:`Two Laplace equations with multiple linear combination constraints <diffusion-laplace_coupling_lcbcs>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-laplace_fluid_2d.png
             :target: diffusion-laplace_fluid_2d.html

             :ref:`A Laplace equation that models the flow of "dry water" around an obstacle shaped like a Citroen CX <diffusion-laplace_fluid_2d>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-laplace_iga_interactive.png
             :target: diffusion-laplace_iga_interactive.html

             :ref:`Laplace equation with Dirichlet boundary conditions solved in a single patch NURBS domain using the isogeometric analysis (IGA) approach, using commands for interactive use <diffusion-laplace_iga_interactive>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-laplace_refine_interactive.png
             :target: diffusion-laplace_refine_interactive.html

             :ref:`Example of solving Laplace's equation on a block domain refined with level 1 hanging nodes <diffusion-laplace_refine_interactive>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-laplace_shifted_periodic.png
             :target: diffusion-laplace_shifted_periodic.html

             :ref:`Laplace equation with shifted periodic BCs <diffusion-laplace_shifted_periodic>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-laplace_time_ebcs.png
             :target: diffusion-laplace_time_ebcs.html

             :ref:`Example explaining how to change Dirichlet boundary conditions depending on time <diffusion-laplace_time_ebcs>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-poisson.png
             :target: diffusion-poisson.html

             :ref:`Laplace equation using the long syntax of keywords <diffusion-poisson>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_field_dependent_material.png
             :target: diffusion-poisson_field_dependent_material.html

             :ref:`Laplace equation with a field-dependent material parameter <diffusion-poisson_field_dependent_material>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_functions.png
             :target: diffusion-poisson_functions.html

             :ref:`Poisson equation with source term <diffusion-poisson_functions>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_iga.png
             :target: diffusion-poisson_iga.html

             :ref:`Poisson equation solved in a single patch NURBS domain using the isogeometric analysis (IGA) approach <diffusion-poisson_iga>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_neumann.png
             :target: diffusion-poisson_neumann.html

             :ref:`The Poisson equation with Neumann boundary conditions on a part of the boundary <diffusion-poisson_neumann>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_nonlinear_material.png
             :target: diffusion-poisson_nonlinear_material.html

             :ref:`Nonlinear Poisson's equation example demonstrating the nonlinear diffusion and nonlinear volume force terms <diffusion-poisson_nonlinear_material>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_parallel_interactive.png
             :target: diffusion-poisson_parallel_interactive.html

             :ref:`Parallel assembling and solving of a Poisson's equation, using commands for interactive use <diffusion-poisson_parallel_interactive>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_parametric_study.png
             :target: diffusion-poisson_parametric_study.html

             :ref:`Poisson equation <diffusion-poisson_parametric_study>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_periodic_boundary_condition.png
             :target: diffusion-poisson_periodic_boundary_condition.html

             :ref:`Transient Laplace equation with a localized power source and periodic boundary conditions <diffusion-poisson_periodic_boundary_condition>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-poisson_short_syntax.png
             :target: diffusion-poisson_short_syntax.html

             :ref:`Laplace equation using the short syntax of keywords <diffusion-poisson_short_syntax>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-sinbc_grad.png
             :target: diffusion-sinbc.html

             :ref:`Laplace equation with Dirichlet boundary conditions given by a sine function and constants <diffusion-sinbc>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-time_advection_diffusion.png
             :target: diffusion-time_advection_diffusion.html

             :ref:`The transient advection-diffusion equation with a given divergence-free advection velocity <diffusion-time_advection_diffusion>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-time_heat_equation_multi_material.png
             :target: diffusion-time_heat_equation_multi_material.html

             :ref:`Transient heat equation with time-dependent source term, three different material domains and Newton type boundary condition loss term <diffusion-time_heat_equation_multi_material>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-time_poisson.png
             :target: diffusion-time_poisson.html

             :ref:`Transient Laplace equation with non-constant initial conditions given by a function <diffusion-time_poisson>`

        - .. figure:: ../images/gallery/thumbnails/diffusion-time_poisson_explicit.png
             :target: diffusion-time_poisson_explicit.html

             :ref:`Transient Laplace equation <diffusion-time_poisson_explicit>`

      * - .. figure:: ../images/gallery/thumbnails/diffusion-time_poisson_interactive-time_poisson_interactive_probe_04.png
             :target: diffusion-time_poisson_interactive.html

             :ref:`Transient Laplace equation (heat equation) with non-constant initial conditions given by a function, using commands for interactive use <diffusion-time_poisson_interactive>`

        - ..

        - ..

   Homogenization
   ^^^^^^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/homogenization-linear_homogenization.png
             :target: homogenization-linear_homogenization.html

             :ref:`Compute homogenized elastic coefficients for a given heterogeneous linear elastic microstructure <homogenization-linear_homogenization>`

        - .. figure:: ../images/gallery/thumbnails/homogenization-nonlinear_hyperelastic_mM.png
             :target: homogenization-nonlinear_hyperelastic_mM.html

             :ref:`Homogenized nonlinear hyperelastic material with evolving microstructure deformation in each macroscopic quadrature point <homogenization-nonlinear_hyperelastic_mM>`

        - .. figure:: ../images/gallery/thumbnails/homogenization-perfusion_micro_etaA_YM.png
             :target: homogenization-perfusion_micro.html

             :ref:`Homogenization of the Darcy flow in a thin porous layer <homogenization-perfusion_micro>`

      * - .. figure:: ../images/gallery/thumbnails/homogenization-rs_correctors.png
             :target: homogenization-rs_correctors.html

             :ref:`Compute homogenized elastic coefficients for a given microstructure <homogenization-rs_correctors>`

        - ..

        - ..

   Large Deformation
   ^^^^^^^^^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/large_deformation-active_fibres.png
             :target: large_deformation-active_fibres.html

             :ref:`Nearly incompressible hyperelastic material model with active fibres <large_deformation-active_fibres>`

        - .. figure:: ../images/gallery/thumbnails/large_deformation-balloon.png
             :target: large_deformation-balloon.html

             :ref:`Inflation of a Mooney-Rivlin hyperelastic balloon <large_deformation-balloon>`

        - .. figure:: ../images/gallery/thumbnails/large_deformation-compare_elastic_materials-pressure_displacement.png
             :target: large_deformation-compare_elastic_materials.html

             :ref:`Compare various elastic materials w <large_deformation-compare_elastic_materials>`

      * - .. figure:: ../images/gallery/thumbnails/large_deformation-gen_yeoh_tl_up_interactive-gen_yeoh_tl_up_comparison.png
             :target: large_deformation-gen_yeoh_tl_up_interactive.html

             :ref:`Incompressible generalized Yeoh hyperelastic material model <large_deformation-gen_yeoh_tl_up_interactive>`

        - .. figure:: ../images/gallery/thumbnails/large_deformation-hyperelastic.png
             :target: large_deformation-hyperelastic.html

             :ref:`Nearly incompressible Mooney-Rivlin hyperelastic material model <large_deformation-hyperelastic>`

        - .. figure:: ../images/gallery/thumbnails/large_deformation-hyperelastic_tl_up_interactive-hyperelastic_tl_up_comparison.png
             :target: large_deformation-hyperelastic_tl_up_interactive.html

             :ref:`Incompressible Mooney-Rivlin hyperelastic material model <large_deformation-hyperelastic_tl_up_interactive>`

      * - .. figure:: ../images/gallery/thumbnails/large_deformation-hyperelastic_ul.png
             :target: large_deformation-hyperelastic_ul.html

             :ref:`Nearly incompressible Mooney-Rivlin hyperelastic material model <large_deformation-hyperelastic_ul>`

        - .. figure:: ../images/gallery/thumbnails/large_deformation-hyperelastic_ul_up.png
             :target: large_deformation-hyperelastic_ul_up.html

             :ref:`Compressible Mooney-Rivlin hyperelastic material model <large_deformation-hyperelastic_ul_up>`

        - .. figure:: ../images/gallery/thumbnails/large_deformation-perfusion_tl.png
             :target: large_deformation-perfusion_tl.html

             :ref:`Porous nearly incompressible hyperelastic material with fluid perfusion <large_deformation-perfusion_tl>`

   Linear Elasticity
   ^^^^^^^^^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-dispersion_analysis-frequencies.png
             :target: linear_elasticity-dispersion_analysis.html

             :ref:`Dispersion analysis of a heterogeneous finite scale periodic cell <linear_elasticity-dispersion_analysis>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-elastic_contact_planes.png
             :target: linear_elasticity-elastic_contact_planes.html

             :ref:`Elastic contact planes simulating an indentation test <linear_elasticity-elastic_contact_planes>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-elastic_contact_sphere.png
             :target: linear_elasticity-elastic_contact_sphere.html

             :ref:`Elastic contact sphere simulating an indentation test <linear_elasticity-elastic_contact_sphere>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-elastic_shifted_periodic.png
             :target: linear_elasticity-elastic_shifted_periodic.html

             :ref:`Linear elasticity with linear combination constraints and periodic boundary conditions <linear_elasticity-elastic_shifted_periodic>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-elastodynamic.png
             :target: linear_elasticity-elastodynamic.html

             :ref:`The linear elastodynamics solution of an iron plate impact problem <linear_elasticity-elastodynamic>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-elastodynamic_identification-res00004.png
             :target: linear_elasticity-elastodynamic_identification.html

             :ref:`The linear elastodynamics solution of an iron plate impact problem with identification of material parameters from simulated measurement data <linear_elasticity-elastodynamic_identification>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-its2D_1.png
             :target: linear_elasticity-its2D_1.html

             :ref:`Diametrically point loaded 2-D disk <linear_elasticity-its2D_1>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-its2D_2.png
             :target: linear_elasticity-its2D_2.html

             :ref:`Diametrically point loaded 2-D disk with postprocessing <linear_elasticity-its2D_2>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-its2D_3.png
             :target: linear_elasticity-its2D_3.html

             :ref:`Diametrically point loaded 2-D disk with nodal stress calculation <linear_elasticity-its2D_3>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-its2D_4-its2D_0.png
             :target: linear_elasticity-its2D_4.html

             :ref:`Diametrically point loaded 2-D disk with postprocessing and probes <linear_elasticity-its2D_4>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-its2D_5-its2D_probe_line0.png
             :target: linear_elasticity-its2D_5.html

             :ref:`Diametrically point loaded 2-D disk with postprocessing and probes <linear_elasticity-its2D_5>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-its2D_interactive-its2D_interactive_probe_0.png
             :target: linear_elasticity-its2D_interactive.html

             :ref:`Diametrically point loaded 2-D disk, using commands for interactive use <linear_elasticity-its2D_interactive>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_elastic.png
             :target: linear_elasticity-linear_elastic.html

             :ref:`Linear elasticity with given displacements <linear_elasticity-linear_elastic>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_elastic_damping.png
             :target: linear_elasticity-linear_elastic_damping.html

             :ref:`Time-dependent linear elasticity with a simple damping <linear_elasticity-linear_elastic_damping>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_elastic_iga.png
             :target: linear_elasticity-linear_elastic_iga.html

             :ref:`Linear elasticity solved in a single patch NURBS domain using the isogeometric analysis (IGA) approach <linear_elasticity-linear_elastic_iga>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_elastic_interactive.png
             :target: linear_elasticity-linear_elastic_interactive.html

             :ref:`Linear elasticity example using the imperative API <linear_elasticity-linear_elastic_interactive>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_elastic_probes-cylinder_probe_line.png
             :target: linear_elasticity-linear_elastic_probes.html

             :ref:`This example shows how to use the post_process_hook to probe the output data <linear_elasticity-linear_elastic_probes>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_elastic_tractions.png
             :target: linear_elasticity-linear_elastic_tractions.html

             :ref:`Linear elasticity with pressure traction load on a surface and constrained to one-dimensional motion <linear_elasticity-linear_elastic_tractions>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_elastic_up.png
             :target: linear_elasticity-linear_elastic_up.html

             :ref:`Nearly incompressible linear elasticity in mixed displacement-pressure formulation with comments <linear_elasticity-linear_elastic_up>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-linear_viscoelastic.png
             :target: linear_elasticity-linear_viscoelastic.html

             :ref:`Linear viscoelasticity with pressure traction load on a surface and constrained to one-dimensional motion <linear_elasticity-linear_viscoelastic>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-material_nonlinearity.png
             :target: linear_elasticity-material_nonlinearity.html

             :ref:`Example demonstrating how a linear elastic term can be used to solve an elasticity problem with a material nonlinearity <linear_elasticity-material_nonlinearity>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-mixed_mesh.png
             :target: linear_elasticity-mixed_mesh.html

             :ref:`A linear elastic beam loaded with a continuous force <linear_elasticity-mixed_mesh>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-modal_analysis.png
             :target: linear_elasticity-modal_analysis.html

             :ref:`Modal analysis of a linear elastic block in 2D or 3D <linear_elasticity-modal_analysis>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-modal_analysis_declarative.png
             :target: linear_elasticity-modal_analysis_declarative.html

             :ref:`Modal analysis of a wheel set <linear_elasticity-modal_analysis_declarative>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-multi_node_lcbcs.png
             :target: linear_elasticity-multi_node_lcbcs.html

             :ref:`Linear elasticity with multi node linear combination constraints <linear_elasticity-multi_node_lcbcs>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-nodal_lcbcs.png
             :target: linear_elasticity-nodal_lcbcs.html

             :ref:`Linear elasticity with nodal linear combination constraints <linear_elasticity-nodal_lcbcs>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-prestress_fibres.png
             :target: linear_elasticity-prestress_fibres.html

             :ref:`Linear elasticity with a given prestress in one subdomain and a (pre)strain fibre reinforcement in the other <linear_elasticity-prestress_fibres>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-seismic_load.png
             :target: linear_elasticity-seismic_load.html

             :ref:`The linear elastodynamics of an elastic body loaded by a given base motion <linear_elasticity-seismic_load>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-shell10x_cantilever.png
             :target: linear_elasticity-shell10x_cantilever.html

             :ref:`Bending of a long thin cantilever beam, declarative problem description <linear_elasticity-shell10x_cantilever>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-shell10x_cantilever_interactive-shell10x_cantilever_convergence_bent.png
             :target: linear_elasticity-shell10x_cantilever_interactive.html

             :ref:`Bending of a long thin cantilever beam, imperative problem description <linear_elasticity-shell10x_cantilever_interactive>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-truss_bridge.png
             :target: linear_elasticity-truss_bridge.html

             :ref:`An example demonstrating the usage of the truss elements in 2D <linear_elasticity-truss_bridge>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-truss_bridge3d_Solid.png
             :target: linear_elasticity-truss_bridge3d.html

             :ref:`An example demonstrating the usage of the truss structural elements in 3D <linear_elasticity-truss_bridge3d>`

        - .. figure:: ../images/gallery/thumbnails/linear_elasticity-two_bodies_contact.png
             :target: linear_elasticity-two_bodies_contact.html

             :ref:`Contact of two elastic bodies with a penalty function for enforcing the contact constraints <linear_elasticity-two_bodies_contact>`

      * - .. figure:: ../images/gallery/thumbnails/linear_elasticity-wedge_mesh.png
             :target: linear_elasticity-wedge_mesh.html

             :ref:`A linear elastic beam loaded with a continuous force <linear_elasticity-wedge_mesh>`

        - ..

        - ..

   Miscellaneous
   ^^^^^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/miscellaneous-live_plot-live_plot.png
             :target: miscellaneous-live_plot.html

             :ref:`Live plot demonstration <miscellaneous-live_plot>`

        - .. figure:: ../images/gallery/thumbnails/miscellaneous-refine_evp-h-refinement-0-laplace-lagrange-primme-none-a.png
             :target: miscellaneous-refine_evp.html

             :ref:`Plot the convergence of eigenvalues (or corresponding frequencies) of an eigenvalue problem to an analytical solution, when applying the uniform mesh refinement <miscellaneous-refine_evp>`

        - ..

   Multi Physics
   ^^^^^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/multi_physics-biot.png
             :target: multi_physics-biot.html

             :ref:`Biot problem - deformable porous medium <multi_physics-biot>`

        - .. figure:: ../images/gallery/thumbnails/multi_physics-biot_npbc.png
             :target: multi_physics-biot_npbc.html

             :ref:`Biot problem - deformable porous medium with the no-penetration boundary condition on a boundary region <multi_physics-biot_npbc>`

        - .. figure:: ../images/gallery/thumbnails/multi_physics-biot_npbc_lagrange.png
             :target: multi_physics-biot_npbc_lagrange.html

             :ref:`Biot problem - deformable porous medium with the no-penetration boundary condition on a boundary region enforced using Lagrange multipliers <multi_physics-biot_npbc_lagrange>`

      * - .. figure:: ../images/gallery/thumbnails/multi_physics-biot_parallel_interactive.png
             :target: multi_physics-biot_parallel_interactive.html

             :ref:`Parallel assembling and solving of a Biot problem (deformable porous medium), using commands for interactive use <multi_physics-biot_parallel_interactive>`

        - .. figure:: ../images/gallery/thumbnails/multi_physics-biot_short_syntax.png
             :target: multi_physics-biot_short_syntax.html

             :ref:`Biot problem - deformable porous medium with a no-penetration boundary condition imposed in the weak sense on a boundary region, using the short syntax of keywords <multi_physics-biot_short_syntax>`

        - .. figure:: ../images/gallery/thumbnails/multi_physics-piezo_elasticity.png
             :target: multi_physics-piezo_elasticity.html

             :ref:`Piezo-elasticity problem - linear elastic material with piezoelectric effects <multi_physics-piezo_elasticity>`

      * - .. figure:: ../images/gallery/thumbnails/multi_physics-piezo_elasticity_macro.png
             :target: multi_physics-piezo_elasticity_macro.html

             :ref:`Piezo-elasticity problem - homogenization of a piezoelectric linear elastic matrix with embedded metalic electrodes, see [1] for details <multi_physics-piezo_elasticity_macro>`

        - .. figure:: ../images/gallery/thumbnails/multi_physics-piezo_elastodynamic.png
             :target: multi_physics-piezo_elastodynamic.html

             :ref:`The linear elastodynamics of a piezoelectric body loaded by a given base motion <multi_physics-piezo_elastodynamic>`

        - .. figure:: ../images/gallery/thumbnails/multi_physics-thermal_electric.10.png
             :target: multi_physics-thermal_electric.html

             :ref:`First solve the stationary electric conduction problem <multi_physics-thermal_electric>`

      * - .. figure:: ../images/gallery/thumbnails/multi_physics-thermo_elasticity.png
             :target: multi_physics-thermo_elasticity.html

             :ref:`Thermo-elasticity with a given temperature distribution <multi_physics-thermo_elasticity>`

        - .. figure:: ../images/gallery/thumbnails/multi_physics-thermo_elasticity_ess.png
             :target: multi_physics-thermo_elasticity_ess.html

             :ref:`Thermo-elasticity with a computed temperature demonstrating equation sequence solver <multi_physics-thermo_elasticity_ess>`

        - ..

   Navier Stokes
   ^^^^^^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/navier_stokes-navier_stokes.png
             :target: navier_stokes-navier_stokes.html

             :ref:`Navier-Stokes equations for incompressible fluid flow <navier_stokes-navier_stokes>`

        - .. figure:: ../images/gallery/thumbnails/navier_stokes-navier_stokes2d.png
             :target: navier_stokes-navier_stokes2d.html

             :ref:`Navier-Stokes equations for incompressible fluid flow in 2D <navier_stokes-navier_stokes2d>`

        - .. figure:: ../images/gallery/thumbnails/navier_stokes-navier_stokes2d_iga.png
             :target: navier_stokes-navier_stokes2d_iga.html

             :ref:`Navier-Stokes equations for incompressible fluid flow in 2D solved in a single patch NURBS domain using the isogeometric analysis (IGA) approach <navier_stokes-navier_stokes2d_iga>`

      * - .. figure:: ../images/gallery/thumbnails/navier_stokes-stabilized_navier_stokes.png
             :target: navier_stokes-stabilized_navier_stokes.html

             :ref:`Stabilized Navier-Stokes problem with grad-div, SUPG and PSPG stabilization solved by a custom Oseen solver <navier_stokes-stabilized_navier_stokes>`

        - .. figure:: ../images/gallery/thumbnails/navier_stokes-stokes.png
             :target: navier_stokes-stokes.html

             :ref:`Stokes equations for incompressible fluid flow <navier_stokes-stokes>`

        - .. figure:: ../images/gallery/thumbnails/navier_stokes-stokes_slip_bc.png
             :target: navier_stokes-stokes_slip_bc.html

             :ref:`Incompressible Stokes flow with Navier (slip) boundary conditions, flow driven by a moving wall and a small diffusion for stabilization <navier_stokes-stokes_slip_bc>`

   Phononic
   ^^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/phononic-band_gaps-band_gaps.png
             :target: phononic-band_gaps.html

             :ref:`Acoustic band gaps in a strongly heterogeneous elastic body, detected using homogenization techniques <phononic-band_gaps>`

        - .. figure:: ../images/gallery/thumbnails/phononic-band_gaps_rigid-band_gaps_rigid.png
             :target: phononic-band_gaps_rigid.html

             :ref:`Acoustic band gaps in a strongly heterogeneous elastic body with a rigid inclusion, detected using homogenization techniques <phononic-band_gaps_rigid>`

        - ..

   Quantum
   ^^^^^^^
   .. list-table::
      :align: center
      :class: gallery

      * - .. figure:: ../images/gallery/thumbnails/quantum-boron.png
             :target: quantum-boron.html

             :ref:`Boron atom with 1 electron <quantum-boron>`

        - .. figure:: ../images/gallery/thumbnails/quantum-hydrogen.png
             :target: quantum-hydrogen.html

             :ref:`Hydrogen atom <quantum-hydrogen>`

        - .. figure:: ../images/gallery/thumbnails/quantum-oscillator.png
             :target: quantum-oscillator.html

             :ref:`Quantum oscillator <quantum-oscillator>`

      * - .. figure:: ../images/gallery/thumbnails/quantum-well.png
             :target: quantum-well.html

             :ref:`Quantum potential well <quantum-well>`

        - ..

        - ..
